@@ -1,14 +1,14 @@
 from pythautomata.automata.wheighted_automaton_definition.weighted_automaton import WeightedState
 from pythautomata.automata.wheighted_automaton_definition.probabilistic_deterministic_finite_automaton import ProbabilisticDeterministicFiniteAutomaton as PDFA
 from pythautomata.base_types.sequence import Sequence
-from pythautomata.model_comparators.wfa_comparison_strategy import WFAComparator as PDFAComparator
+from pythautomata.model_comparators.wfa_tolerance_comparison_strategy import WFAToleranceComparator as PDFAComparator
 from pymodelextractor.learners.observation_table_learners.pdfa_observation_table import PDFAObservationTable, \
      epsilon
 from pymodelextractor.learners.observation_table_learners.translators.pdfa_observation_table_translator import \
      PDFAObservationTableTranslator
 
 from collections import namedtuple
-from pymodelextractor.utilities import pdfa_utils
+from pythautomata.utilities import pdfa_utils
 import numpy as np
 
 
